module Smtpcom
  module Sendapi
    class ClicksReport < ApiResource
      attr_reader :start, :finish, :sender, :campaign, :url, :total

      def initialize(start, finish, sender = nil, campaign = nil, url = nil)
        @start    = start
        @finish   = finish
        @sender   = sender
        @campaign = campaign
        @url      = url
      end

      def all(count = 100, page = 1)
        response = _get(list_url, prepare_params(count, page))
        @total = response['Total']
        format_response response['Data']
      end

      def csv(count = 100, page = 1)
        _get_raw(csv_url, prepare_params(count, page).merge(headers: { 'Accept' => 'text/csv' }))
      end

      def list_url
        @url ? '/clicksbyurl/get' : '/clicks/get'
      end

      def csv_url
        @url ? '/clicksbyurlexport/get' : '/clicksexport/get'
      end

      def prepare_params(count, page)
        attributes = {
          DateFrom: @start.strftime("%m/%d/%Y"),
          DateTo:   @finish.strftime("%m/%d/%Y"),
          Count:    count,
          Page:     page
        }
        attributes[:Sender]     = @sender    if @sender
        attributes[:CampaignID] = @campaign  if @campaign
        attributes[:Url]        = @url       if @url
        attributes
      end

      private

      def format_response(data)
        data.map do |row|
          Utils.format_response_row(row)
        end
      end
    end
  end
end
