module Smtpcom
  module Sendapi
    class Email < ApiResource
      MAPPINGS = {
        subject:          :Subject,
        body_html:        :BodyHtml,
        body_text:        :BodyText,
        template_id:      :TemplateID,
        from:             :From,
        from_name:        :FromName,
        reply_to:         :ReplyTo,
        reply_to_name:    :ReplyToName,
        return_path:      :ReturnPath,
        recipients:       :Recipients,
        recipients_url:   :RecipientsUrl,
        default_recipient_data:     :DefaultRecipientData,
        attachments:      :Attachments,
        campaign:         :Campaign,
        utm_codes:        :UTMCodes,
        email_headers:    :EmailHeaders
      }
      attr_accessor(*MAPPINGS.keys)

      def initialize(*params)
        super(*params)
        @recipients = []
        @attachments = []
        @email_headers = []
      end

      def add_recipient(email, name = nil)
        @recipients << {
          to_address: email,
          to_name:    name
        }
      end

      def add_attachment(name, content_type, body)
        @attachments << {
          name:          name,
          content_type:  content_type,
          content:       body
        }
      end

      def add_header(name, value)
        @email_headers << {
          name:   name,
          value:  value
        }
      end

      def send
        _post '/send', prepare_params, :formatted
      end

      private

      def prepare_params
        {
          Subject:        @subject,
          BodyHtml:       @body_html,
          BodyText:       @body_text,
          TemplateID:     @template_id,
          From:           @from,
          FromName:       @from_name,
          ReplyTo:        @reply_to,
          ReplyToName:    @reply_to_name,
          ReturnPath:     @return_path,
          Recipients:     prepare_recipients,
          RecipientsUrl:  @recipients_url,
          DefaultRecipientData:  @default_recipient_data,
          Attachments:    prepare_attachments,
          Campaign:       @campaign,
          UTMCodes:       @utm_codes,
          EmailHeaders:   prepare_headers
        }
      end

      def prepare_recipients
        @recipients.map do |item|
          {
            ToAddress:  item[:to_address],
            ToName:     item[:to_name]
          }
        end
      end

      def prepare_attachments
        @attachments.map do |item|
          {
            Name:         item[:name],
            ContentType:  item[:content_type],
            Content:      item[:body]
          }
        end
      end

      def prepare_headers
        @email_headers.map do |item|
          {
            Name:   item[:name],
            Value:  item[:value]
          }
        end
      end
    end
  end
end
