module Smtpcom
  module Sendapi
    module Request
      module ClassMethods
        include HTTParty

        attr_reader :response

        def _get(path, params = {}, formatted = false)
          @response = HTTParty.get \
            _url(path),
            headers: _json_headers,
            query: params.merge(_auth_key),
            format: :json
          if formatted
            Utils.format_response_row @response.parsed_response
          else
            @response.parsed_response
          end
        end

        def _get_raw(path, params = {})
          @response = HTTParty.get \
            _url(path),
            headers: (params.delete(:headers) || _json_headers),
            query: params.merge(_auth_key)
          @response.body
        end

        def _post(path, params = {}, formatted = false)
          @response = HTTParty.post \
            _url(path),
            headers: _json_headers,
            body: params.merge(_auth_key).to_json,
            format: :json
          if formatted
            Utils.format_response_row @response.parsed_response
          else
            @response.parsed_response
          end
        end

        def _url(path)
          File.join Smtpcom::Sendapi.api_host, Smtpcom::Sendapi.api_base, path
        end

        def _json_headers
          { 'Content-Type' => 'application/json', 'Accept' => 'application/json' }
        end

        def _auth_key
          { apiKey: Smtpcom::Sendapi.api_key }
        end
      end

      def self.included(base)
        base.extend(ClassMethods)
      end
    end
  end
end
