module Smtpcom
  module Sendapi
    class SendsReport < ApiResource
      attr_reader :start, :finish, :sender, :campaign, :total

      def initialize(start, finish, sender = nil, campaign = nil)
        @start    = start
        @finish   = finish
        @sender   = sender
        @campaign = campaign
      end

      def all(count = 100, page = 1)
        response = _get('/sends/get', prepare_params(count, page))
        @total = response['Total']
        format_response response['Data']
      end

      def failed(count = 100, page = 1)
        response = _get('/sends/failed', prepare_params(count, page))
        @total = response['Total']
        format_response response['Data']
      end

      def prepare_params(count, page)
        attributes = {
          DateFrom: @start.strftime("%m/%d/%Y"),
          DateTo:   @finish.strftime("%m/%d/%Y"),
          Count:    count,
          Page:     page
        }
        attributes[:Sender]     = @sender    if @sender
        attributes[:CampaignID] = @campaign  if @campaign
        attributes
      end

      def format_response(data)
        data.map do |row|
          Utils.format_response_row(row)
        end
      end
    end
  end
end
